/*
 * Setting activity
 *  for Wi-Fi view & select
 */
package jp.gr.java_conf.j_sota.wifiviewandselect;

import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.CheckBoxPreference;
import android.preference.ListPreference;
import android.preference.Preference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceScreen;
import android.preference.Preference.OnPreferenceClickListener;

public class MainSettingActivity extends PreferenceActivity {

	private static final int PREFERENCE_LED_COLOR_SET = 234;

	private Intent mReturnIntent;
	private LedColorList mLedColorList;

	/**
	 * Create main setting activity
	 * @param savedInstanceState
	 */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		addPreferencesFromResource(R.xml.preference);

		// Receive LED color setting data from main activity
		Intent intent = getIntent();
		mLedColorList = intent.getParcelableExtra(getString(R.string.key_led_setting));

		// Get interval setting from default preference
		ListPreference interval = (ListPreference)getPreferenceScreen().findPreference(getString(R.string.key_interval));
		interval.setSummary(getString(R.string.menu_scan_interval_summary, interval.getEntry()));

		// Get connect notification dialog  ON/OFF switch setting from default preference
		CheckBoxPreference notifyOnOff = (CheckBoxPreference)getPreferenceScreen().findPreference(getString(R.string.key_notify_switch));

		// Get LED ON/OFF switch setting from default preference
		CheckBoxPreference ledOnOff = (CheckBoxPreference)getPreferenceScreen().findPreference(getString(R.string.key_led_switch));

		// Create Intent for return data to main activity
		mReturnIntent = new Intent();
		mReturnIntent.putExtra(getString(R.string.key_interval), interval.getValue());
		mReturnIntent.putExtra(getString(R.string.key_notify_switch), notifyOnOff.isChecked());
		mReturnIntent.putExtra(getString(R.string.key_led_switch), ledOnOff.isChecked());
		mReturnIntent.putExtra(getString(R.string.key_led_setting), mLedColorList);
		setResult(RESULT_OK, mReturnIntent);

		// Set click listener for LED color setting
		CharSequence csScreenPrefParent = getText(R.string.key_set_each_led_color);
		PreferenceScreen nextMove1 = (PreferenceScreen) findPreference(csScreenPrefParent);
		nextMove1.setOnPreferenceClickListener(new OnPreferenceClickListener() {

			/**
			 * Click LED color setting preference
			 * @param preference	Preference
			 */
			@Override
			public boolean onPreferenceClick(Preference preference) {
				// Start LED color setting activity
				Intent intent = new Intent(getApplication(), (Class<?>)LedColorSettingActivity.class);
				intent.putExtra(getString(R.string.key_led_setting), mLedColorList);
				startActivityForResult(intent, PREFERENCE_LED_COLOR_SET);
				return true;
			}
		});
	}

	/**
	 * Return from child activity
	 */
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		switch(requestCode) {
		case PREFERENCE_LED_COLOR_SET:
			if (data != null) {
				// Receive LED color setting data
				mLedColorList = data.getParcelableExtra(getString(R.string.key_led_setting));

				// Overwrite return intent data
				mReturnIntent.putExtra(getString(R.string.key_led_setting), mLedColorList);
			}
			break;
		}
	}

	/**
	 * Resume
	 */
	@Override
	protected void onResume() {
		super.onResume();
		// Register preference change listener
		getPreferenceScreen().getSharedPreferences().registerOnSharedPreferenceChangeListener(listener);
	}

	/**
	 * Pause
	 */
	@Override
	protected void onPause() {
		super.onPause();
		// Unregister preference change listener
		getPreferenceScreen().getSharedPreferences().unregisterOnSharedPreferenceChangeListener(listener);
	}

	/**
	 * Preference changed listener
	 */
	private SharedPreferences.OnSharedPreferenceChangeListener listener =
		new SharedPreferences.OnSharedPreferenceChangeListener() {

		/**
		 * This method is called when preference is changed.
		 * Change summary text on the preference screen.
		 * aSave setting data to return intent.
		 * @param sharedPreferences		Preference
		 * @param key					Key
		 */
		public void onSharedPreferenceChanged(SharedPreferences sharedPreferences, String key) {
			if (key.equals(getString(R.string.key_interval))) {
				ListPreference interval = (ListPreference)getPreferenceScreen().findPreference(getString(R.string.key_interval));
				// Change summary text
				interval.setSummary(getString(R.string.menu_scan_interval_summary, interval.getEntry()));
				// Save setting to return intent
				mReturnIntent.putExtra(getString(R.string.key_interval), interval.getValue());
			} else if (key.equals(getString(R.string.key_led_switch))) {
				// Save setting to return intent
				CheckBoxPreference ledOnOff = (CheckBoxPreference)getPreferenceScreen().findPreference(getString(R.string.key_led_switch));
				mReturnIntent.putExtra(getString(R.string.key_led_switch), ledOnOff.isChecked());
			} else if (key.equals(getString(R.string.key_notify_switch))) {
				// Save setting to return intent
				CheckBoxPreference notifyOnOff = (CheckBoxPreference)getPreferenceScreen().findPreference(getString(R.string.key_notify_switch));
				mReturnIntent.putExtra(getString(R.string.key_notify_switch), notifyOnOff.isChecked());
			}
		}
	};
}
